=== modified file 'drizzled/Makefile.am'
--- drizzled/Makefile.am	2009-08-27 00:39:15 +0000
+++ drizzled/Makefile.am	2009-09-15 21:01:42 +0000
@@ -27,6 +27,7 @@
 nobase_dist_drizzledinclude_HEADERS = \
 		alter_column.h \
 		alter_drop.h \
+		alter_info.h \
 		atomic/gcc_traits.h \
 		atomic/pthread_traits.h \
 		atomic/sun_studio.h \
@@ -413,6 +414,7 @@
 		util/test.h
 
 drizzled_SOURCES = \
+		alter_info.cc \
 		authentication.cc \
 		cached_item.cc \
 		calendar.cc \
@@ -440,8 +442,8 @@
 		statement/optimize.cc \
 		statement/release_savepoint.cc \
 		statement/rename_table.cc \
-                statement/replace.cc \
-                statement/replace_select.cc \
+		statement/replace.cc \
+		statement/replace_select.cc \
 		statement/rollback.cc \
 		statement/rollback_to_savepoint.cc \
 		statement/savepoint.cc \

=== added file 'drizzled/alter_info.cc'
--- drizzled/alter_info.cc	1970-01-01 00:00:00 +0000
+++ drizzled/alter_info.cc	2009-09-15 21:01:42 +0000
@@ -0,0 +1,95 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2009 Sun Microsystems
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+/**
+ * @file Implementation of the AlterInfo class
+ */
+
+#include "drizzled/server_includes.h"
+#include "drizzled/alter_info.h"
+#include "drizzled/alter_drop.h"
+#include "drizzled/alter_column.h"
+#include "drizzled/key.h"
+#include "drizzled/create_field.h"
+
+AlterInfo::AlterInfo() :
+  flags(),
+  keys_onoff(LEAVE_AS_IS),
+  tablespace_op(NO_TABLESPACE_OP),
+  no_parts(0),
+  build_method(HA_BUILD_DEFAULT),
+  datetime_field(NULL),
+  error_if_not_empty(false)
+{}
+
+void AlterInfo::reset()
+{
+  drop_list.empty();
+  alter_list.empty();
+  key_list.empty();
+  create_list.empty();
+  flags.reset();
+  keys_onoff= LEAVE_AS_IS;
+  tablespace_op= NO_TABLESPACE_OP;
+  no_parts= 0;
+  build_method= HA_BUILD_DEFAULT;
+  datetime_field= 0;
+  error_if_not_empty= false;
+}
+
+/**
+  Construct a copy of this object to be used for mysql_alter_table
+  and mysql_create_table.
+
+  Historically, these two functions modify their AlterInfo
+  arguments. This behaviour breaks re-execution of prepared
+  statements and stored procedures and is compensated by always
+  supplying a copy of AlterInfo to these functions.
+
+  @return You need to use check the error in Session for out
+  of memory condition after calling this function.
+*/
+AlterInfo::AlterInfo(const AlterInfo &rhs, MEM_ROOT *mem_root) :
+  drop_list(rhs.drop_list, mem_root),
+  alter_list(rhs.alter_list, mem_root),
+  key_list(rhs.key_list, mem_root),
+  create_list(rhs.create_list, mem_root),
+  flags(rhs.flags),
+  keys_onoff(rhs.keys_onoff),
+  tablespace_op(rhs.tablespace_op),
+  no_parts(rhs.no_parts),
+  build_method(rhs.build_method),
+  datetime_field(rhs.datetime_field),
+  error_if_not_empty(rhs.error_if_not_empty)
+{
+  /*
+    Make deep copies of used objects.
+    This is not a fully deep copy - clone() implementations
+    of Alter_drop, Alter_column, Key, foreign_key, Key_part_spec
+    do not copy string constants. At the same length the only
+    reason we make a copy currently is that ALTER/CREATE TABLE
+    code changes input AlterInfo definitions, but string
+    constants never change.
+  */
+  list_copy_and_replace_each_value(drop_list, mem_root);
+  list_copy_and_replace_each_value(alter_list, mem_root);
+  list_copy_and_replace_each_value(key_list, mem_root);
+  list_copy_and_replace_each_value(create_list, mem_root);
+}

=== added file 'drizzled/alter_info.h'
--- drizzled/alter_info.h	1970-01-01 00:00:00 +0000
+++ drizzled/alter_info.h	2009-09-15 21:01:42 +0000
@@ -0,0 +1,100 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2009 Sun Microsystems
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+/**
+ * @file Declaration of the AlterInfo class
+ */
+
+#ifndef DRIZZLED_ALTER_INFO_H
+#define DRIZZLED_ALTER_INFO_H
+
+#include "drizzled/base.h"
+#include "drizzled/enum.h"
+#include "drizzled/sql_list.h" /** @TODO use STL vectors! */
+
+#include <bitset>
+
+/* Some forward declarations needed */
+class CreateField;
+class Alter_drop;
+class Alter_column;
+class Key;
+
+enum enum_alter_info_flags
+{
+  ALTER_ADD_COLUMN= 0,
+  ALTER_DROP_COLUMN,
+  ALTER_CHANGE_COLUMN,
+  ALTER_COLUMN_STORAGE,
+  ALTER_COLUMN_FORMAT,
+  ALTER_COLUMN_ORDER,
+  ALTER_ADD_INDEX,
+  ALTER_DROP_INDEX,
+  ALTER_RENAME,
+  ALTER_ORDER,
+  ALTER_OPTIONS,
+  ALTER_COLUMN_DEFAULT,
+  ALTER_KEYS_ONOFF,
+  ALTER_STORAGE,
+  ALTER_ROW_FORMAT,
+  ALTER_CONVERT,
+  ALTER_FORCE,
+  ALTER_RECREATE,
+  ALTER_TABLE_REORG,
+  ALTER_FOREIGN_KEY
+};
+
+enum tablespace_op_type
+{
+  NO_TABLESPACE_OP,
+  DISCARD_TABLESPACE,
+  IMPORT_TABLESPACE
+};
+
+/**
+ * Contains information about the parsed CREATE or ALTER TABLE statement.
+ *
+ * This structure contains a list of columns or indexes to be created,
+ * altered or dropped.
+ */
+class AlterInfo
+{
+public:
+  List<Alter_drop> drop_list;
+  List<Alter_column> alter_list;
+  List<Key> key_list;
+  List<CreateField> create_list;
+  std::bitset<32> flags;
+  enum enum_enable_or_disable keys_onoff;
+  enum tablespace_op_type tablespace_op;
+  uint32_t no_parts;
+  enum ha_build_method build_method;
+  CreateField *datetime_field;
+  bool error_if_not_empty;
+
+  AlterInfo();
+  AlterInfo(const AlterInfo &rhs, MEM_ROOT *mem_root);
+  void reset();
+private:
+  AlterInfo &operator=(const AlterInfo &rhs); // not implemented
+  AlterInfo(const AlterInfo &rhs);            // not implemented
+};
+
+#endif /* DRIZZLED_ALTER_INFO_H */

=== modified file 'drizzled/handler.h'
--- drizzled/handler.h	2009-08-17 15:34:55 +0000
+++ drizzled/handler.h	2009-09-15 21:01:42 +0000
@@ -70,7 +70,7 @@
 
 class LEX;
 class Select_Lex;
-class Alter_info;
+class AlterInfo;
 class select_result;
 class CreateField;
 class sys_var_str;
@@ -898,13 +898,13 @@
 bool mysql_create_table(Session *session,const char *db, const char *table_name,
                         HA_CREATE_INFO *create_info,
                         drizzled::message::Table *table_proto,
-                        Alter_info *alter_info,
+                        AlterInfo *alter_info,
                         bool tmp_table, uint32_t select_field_count);
 bool mysql_create_table_no_lock(Session *session, const char *db,
                                 const char *table_name,
                                 HA_CREATE_INFO *create_info,
                                 drizzled::message::Table *table_proto,
-                                Alter_info *alter_info,
+                                AlterInfo *alter_info,
                                 bool tmp_table, uint32_t select_field_count);
 
 bool mysql_recreate_table(Session *session, TableList *table_list);

=== modified file 'drizzled/select_create.h'
--- drizzled/select_create.h	2009-06-17 08:30:25 +0000
+++ drizzled/select_create.h	2009-09-15 21:01:42 +0000
@@ -17,7 +17,6 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-
 #ifndef DRIZZLED_SELECT_CREATE_H
 #define DRIZZLED_SELECT_CREATE_H
 
@@ -27,7 +26,7 @@
   HA_CREATE_INFO *create_info;
   drizzled::message::Table *table_proto;
   TableList *select_tables;
-  Alter_info *alter_info;
+  AlterInfo *alter_info;
   Field **field;
   /* lock data for tmp table */
   DRIZZLE_LOCK *m_lock;
@@ -37,7 +36,7 @@
   select_create (TableList *table_arg,
 		 HA_CREATE_INFO *create_info_par,
                  drizzled::message::Table *proto,
-                 Alter_info *alter_info_arg,
+                 AlterInfo *alter_info_arg,
 		 List<Item> &select_fields,enum_duplicates duplic, bool ignore,
                  TableList *select_tables_arg)
     :select_insert (NULL, NULL, &select_fields, 0, 0, duplic, ignore),

=== modified file 'drizzled/sql_insert.cc'
--- drizzled/sql_insert.cc	2009-08-24 14:57:56 +0000
+++ drizzled/sql_insert.cc	2009-09-15 21:01:42 +0000
@@ -1446,7 +1446,7 @@
 static Table *create_table_from_items(Session *session, HA_CREATE_INFO *create_info,
                                       TableList *create_table,
 				      message::Table *table_proto,
-                                      Alter_info *alter_info,
+                                      AlterInfo *alter_info,
                                       List<Item> *items,
                                       DRIZZLE_LOCK **lock)
 {

=== modified file 'drizzled/sql_lex.cc'
--- drizzled/sql_lex.cc	2009-08-16 14:14:39 +0000
+++ drizzled/sql_lex.cc	2009-09-15 21:01:42 +0000
@@ -1265,46 +1265,6 @@
   }
 }
 
-/**
-  Construct a copy of this object to be used for mysql_alter_table
-  and mysql_create_table.
-
-  Historically, these two functions modify their Alter_info
-  arguments. This behaviour breaks re-execution of prepared
-  statements and stored procedures and is compensated by always
-  supplying a copy of Alter_info to these functions.
-
-  @return You need to use check the error in Session for out
-  of memory condition after calling this function.
-*/
-Alter_info::Alter_info(const Alter_info &rhs, MEM_ROOT *mem_root)
-  :drop_list(rhs.drop_list, mem_root),
-  alter_list(rhs.alter_list, mem_root),
-  key_list(rhs.key_list, mem_root),
-  create_list(rhs.create_list, mem_root),
-  flags(rhs.flags),
-  keys_onoff(rhs.keys_onoff),
-  tablespace_op(rhs.tablespace_op),
-  no_parts(rhs.no_parts),
-  build_method(rhs.build_method),
-  datetime_field(rhs.datetime_field),
-  error_if_not_empty(rhs.error_if_not_empty)
-{
-  /*
-    Make deep copies of used objects.
-    This is not a fully deep copy - clone() implementations
-    of Alter_drop, Alter_column, Key, foreign_key, Key_part_spec
-    do not copy string constants. At the same length the only
-    reason we make a copy currently is that ALTER/CREATE TABLE
-    code changes input Alter_info definitions, but string
-    constants never change.
-  */
-  list_copy_and_replace_each_value(drop_list, mem_root);
-  list_copy_and_replace_each_value(alter_list, mem_root);
-  list_copy_and_replace_each_value(key_list, mem_root);
-  list_copy_and_replace_each_value(create_list, mem_root);
-}
-
 void trim_whitespace(const CHARSET_INFO * const cs, LEX_STRING *str)
 {
   /*

=== modified file 'drizzled/sql_lex.h'
--- drizzled/sql_lex.h	2009-08-17 21:30:20 +0000
+++ drizzled/sql_lex.h	2009-09-15 21:01:42 +0000
@@ -34,6 +34,7 @@
 #include "drizzled/function/math/real.h"
 #include "drizzled/alter_drop.h"
 #include "drizzled/alter_column.h"
+#include "drizzled/alter_info.h"
 #include "drizzled/key.h"
 #include "drizzled/foreign_key.h"
 #include "drizzled/item/param.h"
@@ -102,13 +103,6 @@
   ROLLUP_TYPE
 };
 
-enum tablespace_op_type
-{
-  NO_TABLESPACE_OP,
-  DISCARD_TABLESPACE,
-  IMPORT_TABLESPACE
-};
-
 /*
   The state of the lex parsing for selects
 
@@ -640,82 +634,6 @@
     first_select()->next_select()->linkage == UNION_TYPE;
 }
 
-enum enum_alter_info_flags
-{
-  ALTER_ADD_COLUMN= 0,
-  ALTER_DROP_COLUMN,
-  ALTER_CHANGE_COLUMN,
-  ALTER_COLUMN_STORAGE,
-  ALTER_COLUMN_FORMAT,
-  ALTER_COLUMN_ORDER,
-  ALTER_ADD_INDEX,
-  ALTER_DROP_INDEX,
-  ALTER_RENAME,
-  ALTER_ORDER,
-  ALTER_OPTIONS,
-  ALTER_COLUMN_DEFAULT,
-  ALTER_KEYS_ONOFF,
-  ALTER_STORAGE,
-  ALTER_ROW_FORMAT,
-  ALTER_CONVERT,
-  ALTER_FORCE,
-  ALTER_RECREATE,
-  ALTER_TABLE_REORG,
-  ALTER_FOREIGN_KEY
-};
-
-/**
-  @brief Parsing data for CREATE or ALTER Table.
-
-  This structure contains a list of columns or indexes to be created,
-  altered or dropped.
-*/
-
-class Alter_info
-{
-public:
-  List<Alter_drop> drop_list;
-  List<Alter_column> alter_list;
-  List<Key> key_list;
-  List<CreateField> create_list;
-  std::bitset<32> flags;
-  enum enum_enable_or_disable keys_onoff;
-  enum tablespace_op_type tablespace_op;
-  uint32_t no_parts;
-  enum ha_build_method build_method;
-  CreateField *datetime_field;
-  bool error_if_not_empty;
-
-  Alter_info() :
-    flags(),
-    keys_onoff(LEAVE_AS_IS),
-    tablespace_op(NO_TABLESPACE_OP),
-    no_parts(0),
-    build_method(HA_BUILD_DEFAULT),
-    datetime_field(NULL),
-    error_if_not_empty(false)
-  {}
-
-  void reset()
-  {
-    drop_list.empty();
-    alter_list.empty();
-    key_list.empty();
-    create_list.empty();
-    flags.reset();
-    keys_onoff= LEAVE_AS_IS;
-    tablespace_op= NO_TABLESPACE_OP;
-    no_parts= 0;
-    build_method= HA_BUILD_DEFAULT;
-    datetime_field= 0;
-    error_if_not_empty= false;
-  }
-  Alter_info(const Alter_info &rhs, MEM_ROOT *mem_root);
-private:
-  Alter_info &operator=(const Alter_info &rhs); // not implemented
-  Alter_info(const Alter_info &rhs);            // not implemented
-};
-
 enum xa_option_words
 {
   XA_NONE
@@ -960,7 +878,7 @@
   bool tx_release;
   /* Was the IGNORE symbol found in statement */
   bool ignore;
-  Alter_info alter_info;
+  AlterInfo alter_info;
 
   /*
     Pointers to part of LOAD DATA statement that should be rewritten

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2009-09-15 20:04:54 +0000
+++ drizzled/sql_table.cc	2009-09-15 21:01:42 +0000
@@ -900,7 +900,7 @@
 
 int mysql_prepare_create_table(Session *session,
                                HA_CREATE_INFO *create_info,
-                               Alter_info *alter_info,
+                               AlterInfo *alter_info,
                                bool tmp_table,
                                uint32_t *db_options,
                                handler *file,
@@ -1666,7 +1666,7 @@
                                 const char *db, const char *table_name,
                                 HA_CREATE_INFO *create_info,
 				message::Table *table_proto,
-                                Alter_info *alter_info,
+                                AlterInfo *alter_info,
                                 bool internal_tmp_table,
                                 uint32_t select_field_count)
 {
@@ -1866,7 +1866,7 @@
 bool mysql_create_table(Session *session, const char *db, const char *table_name,
                         HA_CREATE_INFO *create_info,
 			message::Table *table_proto,
-                        Alter_info *alter_info,
+                        AlterInfo *alter_info,
                         bool internal_tmp_table,
                         uint32_t select_field_count)
 {
@@ -2712,7 +2712,7 @@
 bool mysql_recreate_table(Session *session, TableList *table_list)
 {
   HA_CREATE_INFO create_info;
-  Alter_info alter_info;
+  AlterInfo alter_info;
   message::Table table_proto;
 
   assert(!table_list->next_global);

=== modified file 'drizzled/sql_table.h'
--- drizzled/sql_table.h	2009-09-15 20:04:54 +0000
+++ drizzled/sql_table.h	2009-09-15 21:01:42 +0000
@@ -48,7 +48,7 @@
                        HA_CREATE_INFO *create_info,
                        drizzled::message::Table *create_proto,
                        TableList *table_list,
-                       Alter_info *alter_info,
+                       AlterInfo *alter_info,
                        uint32_t order_num, order_st *order, bool ignore);
 bool mysql_checksum_table(Session* session, TableList* table_list,
                           HA_CHECK_OPT* check_opt);
@@ -93,7 +93,7 @@
 */
 int mysql_prepare_create_table(Session *session,
                                HA_CREATE_INFO *create_info,
-                               Alter_info *alter_info,
+                               AlterInfo *alter_info,
                                bool tmp_table,
                                uint32_t *db_options,
                                handler *file,

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2009-09-15 20:04:54 +0000
+++ drizzled/statement/alter_table.cc	2009-09-15 21:01:42 +0000
@@ -44,14 +44,14 @@
                                       Table *table,
                                       HA_CREATE_INFO *create_info,
                                       message::Table *table_proto,
-                                      Alter_info *alter_info);
+                                      AlterInfo *alter_info);
 static int create_temporary_table(Session *session,
                                   Table *table,
                                   char *new_db,
                                   char *tmp_name,
                                   HA_CREATE_INFO *create_info,
                                   message::Table *create_proto,
-                                  Alter_info *alter_info);
+                                  AlterInfo *alter_info);
 
 bool statement::AlterTable::execute()
 {
@@ -68,7 +68,7 @@
      referenced from this structure will be modified.
    */
   HA_CREATE_INFO create_info(session->lex->create_info);
-  Alter_info alter_info(session->lex->alter_info, session->mem_root);
+  AlterInfo alter_info(session->lex->alter_info, session->mem_root);
 
   if (session->is_fatal_error) /* out of memory creating a copy of alter_info */
   {
@@ -147,12 +147,11 @@
                  Table instructions
   @retval false  success
 */
-
-static bool
-mysql_prepare_alter_table(Session *session, Table *table,
-                          HA_CREATE_INFO *create_info,
-                          message::Table *table_proto,
-                          Alter_info *alter_info)
+static bool mysql_prepare_alter_table(Session *session,
+                                      Table *table,
+                                      HA_CREATE_INFO *create_info,
+                                      message::Table *table_proto,
+                                      AlterInfo *alter_info)
 {
   /* New column definitions are added here */
   List<CreateField> new_create_list;
@@ -492,10 +491,9 @@
 }
 
 /* table_list should contain just one table */
-static int
-mysql_discard_or_import_tablespace(Session *session,
-                                   TableList *table_list,
-                                   enum tablespace_op_type tablespace_op)
+static int mysql_discard_or_import_tablespace(Session *session,
+                                              TableList *table_list,
+                                              enum tablespace_op_type tablespace_op)
 {
   Table *table;
   bool discard;
@@ -551,8 +549,7 @@
   return -1;
 }
 
-
-/*
+/**
   Manages enabling/disabling of indexes for ALTER Table
 
   SYNOPSIS
@@ -566,9 +563,7 @@
     false  OK
     true   Error
 */
-
-static
-bool alter_table_manage_keys(Table *table, int indexes_were_disabled,
+static bool alter_table_manage_keys(Table *table, int indexes_were_disabled,
                              enum enum_enable_or_disable keys_onoff)
 {
   int error= 0;
@@ -596,7 +591,7 @@
   return(error);
 }
 
-/*
+/**
   Alter table
 
   SYNOPSIS
@@ -637,14 +632,13 @@
     false  OK
     true   Error
 */
-
 bool mysql_alter_table(Session *session,
                        char *new_db,
                        char *new_name,
                        HA_CREATE_INFO *create_info,
                        message::Table *create_proto,
                        TableList *table_list,
-                       Alter_info *alter_info,
+                       AlterInfo *alter_info,
                        uint32_t order_num,
                        order_st *order,
                        bool ignore)
@@ -1445,7 +1439,7 @@
                        char *tmp_name,
                        HA_CREATE_INFO *create_info,
                        message::Table *create_proto,
-                       Alter_info *alter_info)
+                       AlterInfo *alter_info)
 {
   int error;
   StorageEngine *old_db_type, *new_db_type;
@@ -1475,7 +1469,7 @@
                                   message::Table* table_proto)
 {
   HA_CREATE_INFO local_create_info;
-  Alter_info alter_info;
+  AlterInfo alter_info;
   bool tmp_table= (create_info->options & HA_LEX_CREATE_TMP_TABLE);
   uint32_t keys= schema_table->table->s->keys;
   uint32_t db_options= 0;

=== modified file 'drizzled/statement/create_index.cc'
--- drizzled/statement/create_index.cc	2009-08-25 18:17:52 +0000
+++ drizzled/statement/create_index.cc	2009-09-15 21:01:42 +0000
@@ -39,7 +39,7 @@
   */
   /* Prepare stack copies to be re-execution safe */
   HA_CREATE_INFO create_info;
-  Alter_info alter_info(session->lex->alter_info, session->mem_root);
+  AlterInfo alter_info(session->lex->alter_info, session->mem_root);
 
   if (session->is_fatal_error) /* out of memory creating a copy of alter_info */
   {

=== modified file 'drizzled/statement/create_table.cc'
--- drizzled/statement/create_table.cc	2009-08-27 00:51:06 +0000
+++ drizzled/statement/create_table.cc	2009-09-15 21:01:42 +0000
@@ -58,10 +58,10 @@
   HA_CREATE_INFO create_info(session->lex->create_info);
   /*
      We need to copy alter_info for the same reasons of re-execution
-     safety, only in case of Alter_info we have to do (almost) a deep
+     safety, only in case of AlterInfo we have to do (almost) a deep
      copy.
    */
-  Alter_info alter_info(session->lex->alter_info, session->mem_root);
+  AlterInfo alter_info(session->lex->alter_info, session->mem_root);
 
   if (session->is_fatal_error)
   {

=== modified file 'drizzled/statement/drop_index.cc'
--- drizzled/statement/drop_index.cc	2009-08-25 18:17:52 +0000
+++ drizzled/statement/drop_index.cc	2009-09-15 21:01:42 +0000
@@ -39,7 +39,7 @@
    */
   /* Prepare stack copies to be re-execution safe */
   HA_CREATE_INFO create_info;
-  Alter_info alter_info(session->lex->alter_info, session->mem_root);
+  AlterInfo alter_info(session->lex->alter_info, session->mem_root);
 
   if (session->is_fatal_error) /* out of memory creating a copy of alter_info */
   {

